home | help
FINGER(1)		     General Commands Manual		       FINGER(1)

NAME
     finger -- user information lookup program

SYNOPSIS
     finger [-46glmpshoT] [user ...] [user@host ...]

DESCRIPTION
     The finger utility displays information about the system users.

     Options are:

     -4      Forces finger to use IPv4 addresses only.

     -6      Forces finger to use IPv6 addresses only.

     -s      Display  the  user's login name, real name, terminal name and write
	     status (as a ``*'' before the terminal name if write permission  is
	     denied),  idle time, login time, and either office location and of-
	     fice phone number, or the remote host.  If -o is given, the  office
	     location  and  office phone number is printed (the default).  If -h
	     is given, the remote host is printed instead.

	     Idle time is in minutes if it is a single integer, hours  and  min-
	     utes  if  a ``:'' is present, or days if a ``d'' is present.  If it
	     is an "*", the login time indicates the time of last login.   Login
	     time  is displayed as the day name if less than 6 days, else month,
	     day; hours and minutes, unless more than six months ago,  in  which
	     case the year is displayed rather than the hours and minutes.

	     Unknown  devices  as  well  as nonexistent idle and login times are
	     displayed as single asterisks.

     -h      When used in conjunction with the -s option, the name of the remote
	     host is displayed instead of the office location and office phone.

     -o      When used in conjunction with the -s option,  the	office	location
	     and  office  phone  information is displayed instead of the name of
	     the remote host.

     -g      This option restricts the gecos output  to  only  the  users'  real
	     name.  It also has the side-effect of restricting the output of the
	     remote host when used in conjunction with the -h option.

     -l      Produce a multi-line format displaying all of the	information  de-
	     scribed  for  the	-s  option as well as the user's home directory,
	     home phone number, login shell, mail status, and  the  contents  of
	     the  files  .forward,  .plan,  .project and .pubkey from the user's
	     home directory.

	     If idle time is at least a minute and less than a day, it	is  pre-
	     sented  in  the  form ``hh:mm''.  Idle times greater than a day are
	     presented as ``d day[s]hh:mm''.

	     Phone numbers specified as eleven digits are printed  as  ``+N-NNN-
	     NNN-NNNN''.   Numbers  specified as ten or seven digits are printed
	     as the appropriate subset of that	string.   Numbers  specified  as
	     five  digits are printed as ``xN-NNNN''.  Numbers specified as four
	     digits are printed as ``xNNNN''.

	     If write permission is denied to the device, the phrase ``(messages
	     off)'' is appended to the line containing the device name.  One en-
	     try per user is displayed with the -l option; if a user  is  logged
	     on multiple times, terminal information is repeated once per login.

	     Mail  status  is  shown as ``No Mail.'' if there is no mail at all,
	     ``Mail last read DDD MMM ## HH:MM YYYY (TZ)''  if	the  person  has
	     looked  at their mailbox since new mail arriving, or ``New mail re-
	     ceived ...'', ``Unread since ...'' if they have new mail.

     -p      Prevent the -l option of finger from displaying the contents of the
	     .forward, .plan, .project and .pubkey files.

     -m      Prevent matching of user names.  User is usually a login name; how-
	     ever, matching will also be done on the users' real  names,  unless
	     the  -m  option is supplied.  All name matching performed by finger
	     is case insensitive.

     -T      Disable the piggybacking of data on the initial connection request.
	     This option is needed to finger hosts with a broken TCP implementa-
	     tion.

     If no options are specified, finger defaults to  the  -l  style  output  if
     operands  are  provided,  otherwise to the -s style.  Note that some fields
     may be missing, in either format, if information is not available for them.

     If no arguments are specified, finger will print an  entry  for  each  user
     currently logged into the system.

     The  finger  utility may be used to look up users on a remote machine.  The
     format is to specify a user as "user@host", or "@host", where  the  default
     output format for the former is the -l style, and the default output format
     for  the latter is the -s style.  The -l option is the only option that may
     be passed to a remote machine.

     If the file .nofinger exists in the user's home directory,  finger  behaves
     as if the user in question does not exist.

     The  optional  finger.conf(5)  configuration  file  can  be used to specify
     aliases.  Since finger(1) is invoked by fingerd(8), aliases will  work  for
     both local and network queries.

ENVIRONMENT
     The  finger  utility utilizes the following environment variable, if it ex-
     ists:

     FINGER	 This variable may be set with favored options to finger.

FILES
     /etc/finger.conf  alias definition data base
     /var/log/lastlog  last login data base

SEE ALSO
     chpass(1), w(1), who(1), finger.conf(5), fingerd(8)

     D. Zimmerman, The Finger User Information	Protocol,  RFC	1288,  December,
     1991.

HISTORY
     The finger command appeared in 3.0BSD.

BUGS
     The  current  FINGER protocol RFC requires that the client keep the connec-
     tion fully open until the server closes.  This prevents the use of the  op-
     timal  three-packet T/TCP exchange.  (Servers which depend on this require-
     ment are bogus but have  nonetheless  been  observed  in  the  Internet  at
     large.)

FreeBSD 5.0			  July 22, 2002 		       FINGER(1)

home | help